import React$1 from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';

type CommonButtonProps = {
	kind?: "dark" | "light";
	focus?: "dark" | "light";
	fullWidth?: boolean;
	className?: string;
	slim?: boolean;
	raw?: boolean;
	noBorder?: boolean;
};

declare const Button: React$1.ForwardRefExoticComponent<{
    onClick?: React$1.MouseEventHandler<HTMLButtonElement> | undefined;
    disabled?: boolean | undefined;
    type?: "button" | "submit" | "reset" | undefined;
} & CommonButtonProps & {
    children?: React$1.ReactNode;
} & React$1.ButtonHTMLAttributes<HTMLButtonElement> & React$1.RefAttributes<HTMLButtonElement>>;

declare const ButtonIcon: React$1.ForwardRefExoticComponent<{
    label?: string | undefined;
    children: React$1.ReactNode;
} & CommonButtonProps & React$1.ButtonHTMLAttributes<HTMLButtonElement> & React$1.RefAttributes<HTMLButtonElement>>;

declare const ButtonLink: React$1.ForwardRefExoticComponent<{
    children?: React$1.ReactNode;
    link?: string | undefined;
    target?: string | undefined;
    maxLabelLength?: number | undefined;
} & {
    onClick?: React$1.MouseEventHandler<HTMLButtonElement> | undefined;
    disabled?: boolean | undefined;
    type?: "button" | "submit" | "reset" | undefined;
} & CommonButtonProps & {
    children?: React$1.ReactNode;
} & React$1.ButtonHTMLAttributes<HTMLButtonElement> & React$1.AnchorHTMLAttributes<HTMLAnchorElement> & React$1.RefAttributes<HTMLAnchorElement>>;

type FooterProps = {
	kind?: "dark" | "light";
	className?: string;
	noPaddings?: boolean;
	row1?: React.ReactNode;
	row2?: React.ReactNode;
};

declare const Footer: ({ className, kind, row1, row2, noPaddings, }: FooterProps) => react_jsx_runtime.JSX.Element;

type SpacingType =
	| undefined
	| string
	| number
	| {
			t?: number;
			r?: number;
			b?: number;
			l?: number;
	  };

interface IconsProps
	extends Omit<React.SVGAttributes<SVGElement>, "spacing"> {
	spacing?: SpacingType;
}

declare const IconClose: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconCopied: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconCopy: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconDelete: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconDog: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconDogInShield: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconEdit: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconRestore: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconSettings: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

declare const IconUser: ({ className, viewBox, spacing, ...rest }: IconsProps) => react_jsx_runtime.JSX.Element;

type MainProps = {
	children: React.ReactNode;
	className?: string;
	raw?: boolean;
};

declare const Main: ({ children, className, raw }: MainProps) => react_jsx_runtime.JSX.Element;

type TextInputProps = {
	label: string;
	name: string;
	labelId?: string;
	helperText?: string;
	error?: boolean;
	focusKind?: "dark" | "light";
	borderKind?: "dark" | "light";
	errorKind?: "dark" | "light";
	raw?: boolean;
	noBorder?: boolean;
} & React.InputHTMLAttributes<HTMLInputElement>;

declare const TextInput: ({ id, name, label, error, raw, className, focusKind, borderKind, errorKind, disabled, noBorder, labelId, type, helperText, ...extraProps }: TextInputProps) => react_jsx_runtime.JSX.Element;

export { Button, ButtonIcon, ButtonLink, Footer, IconClose, IconCopied, IconCopy, IconDelete, IconDog, IconDogInShield, IconEdit, IconRestore, IconSettings, IconUser, Main, TextInput };
